@@ -1,17 +1,27 @@
 """Tests for the object inspection functionality.
 """
+#-----------------------------------------------------------------------------
+#  Copyright (C) 2010-2011 The IPython Development Team.
+#
+#  Distributed under the terms of the BSD License.
+#
+#  The full license is in the file COPYING.txt, distributed with this software.
+#-----------------------------------------------------------------------------
 
-# Copyright (c) IPython Development Team.
-# Distributed under the terms of the Modified BSD License.
-
+#-----------------------------------------------------------------------------
+# Imports
+#-----------------------------------------------------------------------------
 from __future__ import print_function
 
+# Stdlib imports
 import os
 import re
 import sys
 
+# Third-party imports
 import nose.tools as nt
 
+# Our own imports
 from .. import oinspect
 from IPython.core.magic import (Magics, magics_class, line_magic,
                                 cell_magic, line_cell_magic,
@@ -19,10 +29,9 @@ from IPython.core.magic import (Magics, magics_class, line_magic,
                                 register_line_cell_magic)
 from decorator import decorator
 from IPython.testing.decorators import skipif
-from IPython.testing.tools import AssertPrints, AssertNotPrints
+from IPython.testing.tools import AssertPrints
 from IPython.utils.path import compress_user
 from IPython.utils import py3compat
-from IPython.utils.signatures import Signature, Parameter
 
 
 #-----------------------------------------------------------------------------
@@ -40,7 +49,7 @@ ip = get_ipython()
 # defined, if any code is inserted above, the following line will need to be
 # updated.  Do NOT insert any whitespace between the next line and the function
 # definition below.
-THIS_LINE_NUMBER = 43  # Put here the actual number of this line
+THIS_LINE_NUMBER = 52  # Put here the actual number of this line
 def test_find_source_lines():
     nt.assert_equal(oinspect.find_source_lines(test_find_source_lines), 
                     THIS_LINE_NUMBER+1)
@@ -111,14 +120,6 @@ class Call(object):
     def method(self, x, z=2):
         """Some method's docstring"""
 
-class HasSignature(object):
-    """This is the class docstring."""
-    __signature__ = Signature([Parameter('test', Parameter.POSITIONAL_OR_KEYWORD)])
-
-    def __init__(self, *args):
-        """This is the init docstring"""
-
-
 class SimpleClass(object):
     def method(self, x, z=2):
         """Some method's docstring"""
@@ -270,8 +271,7 @@ def test_info():
     nt.assert_equal(i['type_name'], 'type')
     expted_class = str(type(type))  # <class 'type'> (Python 3) or <type 'type'>
     nt.assert_equal(i['base_class'], expted_class)
-    if sys.version_info > (3,):
-        nt.assert_regex(i['string_form'], "<class 'IPython.core.tests.test_oinspect.Call'( at 0x[0-9a-f]{1,9})?>")
+    nt.assert_equal(i['string_form'], "<class 'IPython.core.tests.test_oinspect.Call'>")
     fname = __file__
     if fname.endswith(".pyc"):
         fname = fname[:-1]
@@ -282,8 +282,7 @@ def test_info():
     nt.assert_equal(i['docstring'], Call.__doc__)
     nt.assert_equal(i['source'], None)
     nt.assert_true(i['isclass'])
-    _self_py2 = '' if py3compat.PY3 else 'self, '
-    nt.assert_equal(i['init_definition'], "Call(%sx, y=1)" % _self_py2)
+    nt.assert_equal(i['init_definition'], "Call(self, x, y=1)\n")
     nt.assert_equal(i['init_docstring'], Call.__init__.__doc__)
 
     i = inspector.info(Call, detail_level=1)
@@ -308,14 +307,9 @@ def test_info():
         nt.assert_equal(i['type_name'], 'instance')
         nt.assert_equal(i['docstring'], OldStyle.__doc__)
 
-def test_class_signature():
-    info = inspector.info(HasSignature, 'HasSignature')
-    nt.assert_equal(info['init_definition'], "HasSignature(test)")
-    nt.assert_equal(info['init_docstring'], HasSignature.__init__.__doc__)
-
 def test_info_awkward():
     # Just test that this doesn't throw an error.
-    inspector.info(Awkward())
+    i = inspector.info(Awkward())
 
 def test_bool_raise():
     inspector.info(NoBoolCall())
@@ -341,13 +335,13 @@ if py3compat.PY3:
 @skipif(not py3compat.PY3)
 def test_definition_kwonlyargs():
     i = inspector.info(f_kwarg, oname='f_kwarg')  # analysis:ignore
-    nt.assert_equal(i['definition'], "f_kwarg(pos, *, kwonly)")
+    nt.assert_equal(i['definition'], "f_kwarg(pos, *, kwonly)\n")
 
 def test_getdoc():
     class A(object):
         """standard docstring"""
         pass
-
+    
     class B(object):
         """standard docstring"""
         def getdoc(self):
@@ -399,17 +393,17 @@ def test_property_sources():
 def test_property_docstring_is_in_info_for_detail_level_0():
     class A(object):
         @property
-        def foobar(self):
+        def foobar():
             """This is `foobar` property."""
             pass
 
     ip.user_ns['a_obj'] = A()
-    nt.assert_equal(
+    nt.assert_equals(
         'This is `foobar` property.',
         ip.object_inspect('a_obj.foobar', detail_level=0)['docstring'])
 
     ip.user_ns['a_cls'] = A
-    nt.assert_equal(
+    nt.assert_equals(
         'This is `foobar` property.',
         ip.object_inspect('a_cls.foobar', detail_level=0)['docstring'])
 
@@ -419,57 +413,15 @@ def test_pdef():
     def foo(): pass
     inspector.pdef(foo, 'foo')
 
-
 def test_pinfo_nonascii():
     # See gh-1177
     from . import nonascii2
     ip.user_ns['nonascii2'] = nonascii2
     ip._inspect('pinfo', 'nonascii2', detail_level=1)
 
-
-def test_pinfo_docstring_no_source():
-    """Docstring should be included with detail_level=1 if there is no source"""
-    with AssertPrints('Docstring:'):
-        ip._inspect('pinfo', 'str.format', detail_level=0)
-    with AssertPrints('Docstring:'):
-        ip._inspect('pinfo', 'str.format', detail_level=1)
-
-
-def test_pinfo_no_docstring_if_source():
-    """Docstring should not be included with detail_level=1 if source is found"""
-    def foo():
-        """foo has a docstring"""
-
-    ip.user_ns['foo'] = foo
-
-    with AssertPrints('Docstring:'):
-        ip._inspect('pinfo', 'foo', detail_level=0)
-    with AssertPrints('Source:'):
-        ip._inspect('pinfo', 'foo', detail_level=1)
-    with AssertNotPrints('Docstring:'):
-        ip._inspect('pinfo', 'foo', detail_level=1)
-
-
 def test_pinfo_magic():
     with AssertPrints('Docstring:'):
         ip._inspect('pinfo', 'lsmagic', detail_level=0)
 
     with AssertPrints('Source:'):
         ip._inspect('pinfo', 'lsmagic', detail_level=1)
-
-
-def test_init_colors():
-    # ensure colors are not present in signature info
-    info = inspector.info(HasSignature)
-    init_def = info['init_definition']
-    nt.assert_not_in('[0m', init_def)
-
-
-def test_builtin_init():
-    info = inspector.info(list)
-    init_def = info['init_definition']
-    # Python < 3.4 can't get init definition from builtins,
-    # but still exercise the inspection in case of error-raising bugs.
-    if sys.version_info >= (3,4):
-        nt.assert_is_not_none(init_def)
-
